@@ -1,4 +1,4 @@
 from .classifier import RhythmKMeans
-from .data import get_heat_maps, get_dataset
+from .data import add_instrument_back_pointer, get_heat_maps, get_dataset
 from .metrics import rhythm_similarity
 from .timepoints import get_notes_by_period, get_rhythm_markers_by_beat
