@@ -61,11 +61,11 @@ class RhythmKMeans:
     def is_empty(self):
         return self.k() == 0
 
-    def add_beat_clusters(self, midi_obj, beat_resolution=480, preprocessing='default', min_pitch=0, max_pitch=127):
+    def add_beat_clusters(self, midi_obj, beat_resolution=480, preprocessing='default', pitches=range(0, 128)):
         if self.is_empty():
             raise AssertionError('K-means classifier is empty. Use fit() to generate cluster centers')
 
-        heat_maps = get_heat_maps(midi_obj, beat_resolution=beat_resolution, min_pitch=min_pitch, max_pitch=max_pitch)
+        heat_maps = get_heat_maps(midi_obj, beat_resolution=beat_resolution, pitches=pitches)
         if preprocessing == 'binary':
             heat_maps = np.clip(np.ceil(heat_maps), 0., 1.)
         elif preprocessing == 'quantized':
@@ -79,11 +79,11 @@ class RhythmKMeans:
                                        time=beat * beat_resolution)
             midi_obj.markers.append(marker)
 
-    def get_rhythm_scores(self, midi_obj, beat_resolution=480, min_pitch=0, max_pitch=127):
+    def get_rhythm_scores(self, midi_obj, beat_resolution=480, pitches=range(0, 128)):
         if self.is_empty():
             raise AssertionError('K-means classifier is empty. Use fit() to generate cluster centers')
 
-        heat_maps = get_heat_maps(midi_obj, beat_resolution=beat_resolution, min_pitch=min_pitch, max_pitch=max_pitch)
+        heat_maps = get_heat_maps(midi_obj, beat_resolution=beat_resolution, pitches=pitches)
         types = np.zeros(heat_maps.shape[0])
         centers_by_beats = np.zeros((heat_maps.shape[0], 24))
 
