@@ -10,11 +10,11 @@ def add_instrument_back_pointer(midi_obj):
             note.instrument = instrument
 
 
-def get_heat_maps(midi_obj, n_bins=24, beat_resolution=480, rid_melody=False, min_pitch=0, max_pitch=127):
+def get_heat_maps(midi_obj, n_bins=24, beat_resolution=480, rid_melody=False, is_drum=False, pitches=range(0, 128)):
+    add_instrument_back_pointer(midi_obj)
     notes = []
     for instrument in midi_obj.instruments:
-        if not instrument.is_drum:
-            notes += instrument.notes
+        notes += instrument.notes
     if rid_melody:
         notes = extract_accompaniment(notes)
     notes_by_beats = get_notes_by_period(notes, resolution=beat_resolution)
@@ -24,13 +24,13 @@ def get_heat_maps(midi_obj, n_bins=24, beat_resolution=480, rid_melody=False, mi
             notes=note_set,
             n_bins=n_bins,
             beat_resolution=beat_resolution,
-            min_pitch=min_pitch,
-            max_pitch=max_pitch
+            is_drum=is_drum,
+            pitches=pitches
         )
         for note_set in notes_by_beats])
 
 
-def get_dataset(midi_objs, n_bins=24, beat_resolution=480, rid_melody=False, min_pitch=0, max_pitch=127):
+def get_dataset(midi_objs, n_bins=24, beat_resolution=480, rid_melody=False, is_drum=False, pitches=range(0, 128)):
     dataset = np.zeros((0, 24))
     for midi_obj in midi_objs:
         heat_maps = get_heat_maps(
@@ -38,8 +38,8 @@ def get_dataset(midi_objs, n_bins=24, beat_resolution=480, rid_melody=False, min
             n_bins=n_bins,
             beat_resolution=beat_resolution,
             rid_melody=rid_melody,
-            min_pitch=min_pitch,
-            max_pitch=max_pitch)
+            is_drum=is_drum,
+            pitches=pitches)
         dataset = np.concatenate((dataset, heat_maps))
 
     return dataset
